@@ -22,4 +22,9 @@ class CSVNotFound(NotFoundError):
     pass
 
 class FolderNotFound(NotFoundError):
-    pass
\ No newline at end of file
+    pass
+
+# 解析字典错误
+class ResolveDictError(NotFoundError):
+    pass
+
